==> jaxrs-ri-2.17-sources.jar: org/glassfish/jersey/server/model/internal/VoidVoidDispatcherProvider.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2011-2015 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * http://glassfish.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package org.glassfish.jersey.server.model.internal;

import java.lang.reflect.InvocationHandler;

import javax.ws.rs.ProcessingException;
import javax.ws.rs.container.ResourceContext;
import javax.ws.rs.core.Context;
import javax.ws.rs.core.Response;

import javax.inject.Singleton;

import org.glassfish.jersey.server.ContainerRequest;
import org.glassfish.jersey.server.internal.inject.ConfiguredValidator;
import org.glassfish.jersey.server.model.Invocable;
import org.glassfish.jersey.server.spi.internal.ResourceMethodDispatcher;

/**
 * Specific resource method dispatcher for dispatching requests to a void
 * {@link java.lang.reflect.Method Java method} with no input arguments
 * using a supplied {@link InvocationHandler Java method invocation handler}.
 *
 * @author Marek Potociar (marek.potociar at oracle.com)
 * @author Jakub Podlesak (jakub.podlesak at oracle.com)
 */
@Singleton
final class VoidVoidDispatcherProvider implements ResourceMethodDispatcher.Provider {

    @Context
    private ResourceContext resourceContext;

    private static class VoidToVoidDispatcher extends AbstractJavaResourceMethodDispatcher {

        private VoidToVoidDispatcher(final Invocable resourceMethod,
                                     final InvocationHandler handler,
                                     final ConfiguredValidator validator) {
            super(resourceMethod, handler, validator);
        }

        @Override
        public Response doDispatch(final Object resource, final ContainerRequest containerRequest) throws ProcessingException {
            invoke(containerRequest, resource);
            return Response.noContent().build();
        }
    }

    @Override
    public ResourceMethodDispatcher create(final Invocable resourceMethod,
                                           final InvocationHandler handler,
                                           final ConfiguredValidator validator) {
        if (resourceMethod.getHandlingMethod().getReturnType() != void.class || !resourceMethod.getParameters().isEmpty()) {
            return null;
        }

        return resourceContext.initResource(new VoidToVoidDispatcher(resourceMethod, handler, validator));
    }
}

==> jaxrs-ri-2.28-sources.jar: org/glassfish/jersey/server/model/internal/VoidVoidDispatcherProvider.java <==
/*
 * Copyright (c) 2011, 2018 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0, which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception, which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 */

package org.glassfish.jersey.server.model.internal;

import java.lang.reflect.InvocationHandler;

import javax.ws.rs.ProcessingException;
import javax.ws.rs.container.ResourceContext;
import javax.ws.rs.core.Response;

import javax.inject.Singleton;

import org.glassfish.jersey.server.ContainerRequest;
import org.glassfish.jersey.server.internal.inject.ConfiguredValidator;
import org.glassfish.jersey.server.model.Invocable;
import org.glassfish.jersey.server.spi.internal.ResourceMethodDispatcher;

/**
 * Specific resource method dispatcher for dispatching requests to a void
 * {@link java.lang.reflect.Method Java method} with no input arguments
 * using a supplied {@link InvocationHandler Java method invocation handler}.
 *
 * @author Marek Potociar (marek.potociar at oracle.com)
 * @author Jakub Podlesak (jakub.podlesak at oracle.com)
 */
@Singleton
final class VoidVoidDispatcherProvider implements ResourceMethodDispatcher.Provider {

    private final ResourceContext resourceContext;

    VoidVoidDispatcherProvider(ResourceContext resourceContext) {
        this.resourceContext = resourceContext;
    }

    private static class VoidToVoidDispatcher extends AbstractJavaResourceMethodDispatcher {

        private VoidToVoidDispatcher(final Invocable resourceMethod,
                                     final InvocationHandler handler,
                                     final ConfiguredValidator validator) {
            super(resourceMethod, handler, validator);
        }

        @Override
        public Response doDispatch(final Object resource, final ContainerRequest containerRequest) throws ProcessingException {
            invoke(containerRequest, resource);
            return Response.noContent().build();
        }
    }

    @Override
    public ResourceMethodDispatcher create(final Invocable resourceMethod,
                                           final InvocationHandler handler,
                                           final ConfiguredValidator validator) {
        if (resourceMethod.getHandlingMethod().getReturnType() != void.class || !resourceMethod.getParameters().isEmpty()) {
            return null;
        }

        return resourceContext.initResource(new VoidToVoidDispatcher(resourceMethod, handler, validator));
    }
}
